depman package
==============

Submodules
----------

depman\.apt module
------------------

.. automodule:: depman.apt
    :members:
    :undoc-members:
    :show-inheritance:

depman\.dependency module
-------------------------

.. automodule:: depman.dependency
    :members:
    :undoc-members:
    :show-inheritance:

depman\.globals module
----------------------

.. automodule:: depman.globals
    :members:
    :undoc-members:
    :show-inheritance:

depman\.main module
-------------------

.. automodule:: depman.main
    :members:
    :undoc-members:
    :show-inheritance:

depman\.operation module
------------------------

.. automodule:: depman.operation
    :members:
    :undoc-members:
    :show-inheritance:

depman\.pip module
------------------

.. automodule:: depman.pip
    :members:
    :undoc-members:
    :show-inheritance:

depman\.relation module
-----------------------

.. automodule:: depman.relation
    :members:
    :undoc-members:
    :show-inheritance:

depman\.yatr module
-------------------

.. automodule:: depman.yatr
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: depman
    :members:
    :undoc-members:
    :show-inheritance:
